@@ -7,4 +7,6 @@ if [ -z "$version" ]; then
 fi
 
 sed -i "/^version = .*/c\version = \"$version\"" Cargo.toml
-sed -i "/^Version: .*/c\Version: $version" contrib/rust-cipo.spec
\ No newline at end of file
+sed -i "/^Version: .*/c\Version: $version" contrib/rust-cipo.spec
+sed -i "/\.version\\\(\".*/c\.version\(\"$version\"\)" src/main.rs
+rustfmt src/main.rs
\ No newline at end of file
